# phenocv

## Introduction

**phenocv** is a toolkits for rice high-throught phenotyping using computer vision.

**phenocv** is still in early development stage, and more features will be added in the future.

For label-studio semi-automatic annotation, please refer to [playground](https://github.com/open-mmlab/playground).

For mmdetection training, please refer to [mmdetection](https://github.com/open-mmlab/mmdetection).

For yolo training, please refer to [Ultralytics](https://github.com/ultralytics/ultralytics).

Support for mmdetection and label-studio will be added in the future.

## Installation

Before install the package, make sure you have installed [pytorch](https://pytorch.org/get-started/locally/) and install in the python environment with python>=3.8.

### Install with pip:

```shell
pip install phenocv
```

### Install in editable mode, allow changes to the source code to be immediately available:

```shell
git clone https://github.com/r1cheu/phenocv.git
cd phenocv
pip install -e .
```

## License

This project is released under the [AGPL 3.0 license](LICENSE).

## Citation

If you find this project useful in your research, please consider cite:

```Bibtex
@misc{2023phenocv,
    title={Rice high-throught phenotyping computer vision toolkits},
    author={RuLei Chen},
    howpublished = {\url{https://github.com/r1cheu/phenocv}},
    year={2023}
}
```
